@@ -9,7 +9,7 @@
  * of this code will be considered a derivative work and will
  * be the sole property of me.
  *
-  fileop [-f X ]|[-l # -u #] [-s Y] [-t] [-v] [-e] [-b] [-w]
+  fileop [-f X ]|[-l # -u #] [-s Y] [-t] [-v] [-e] [-b] [-w] [-h] [-d]
        -f # Force factor. X^3 files will be created and removed.
        -l # Lower limit on the value of the Force factor.
        -u # Upper limit on the value of the Force factor.
@@ -19,6 +19,8 @@
        -e # Excel importable format.
        -b Output best case
        -w Output worst case
+       -h Help text
+       -d <dir> specify starting directory.
  *
  * X is a force factor. The total number of files will
  *   be X * X * X   ( X ^ 3 )
@@ -100,16 +102,19 @@ void splash(void);
 void usage(void);
 void bzero();
 void clear_stats();
+int validate(char *, int , char );
 
-#define THISVERSION "        $Revision: 1.37 $"
+#define THISVERSION "        $Revision: 1.40 $"
 /*#define NULL 0*/
 
 char version[]=THISVERSION;
+char thedir[]="."; /* Default is to use the current directory */
 
 int cret;
 int lower, upper,range;
 int i;
 int best, worst;
+int dirlen;
 
 int main(int argc, char **argv)
 {
@@ -118,8 +123,21 @@ int main(int argc, char **argv)
 		usage();
 		exit(1);
 	}
-	while((cret = getopt(argc,argv,"bwetvf:s:l:u: ")) != EOF){
+	while((cret = getopt(argc,argv,"hbwetvf:s:l:u:d: ")) != EOF){
 		switch(cret){
+                case 'h':
+                        usage();
+                        exit(0);
+                        break;
+                case 'd' :
+                        dirlen=strlen(optarg);
+                        if (optarg[dirlen-1]=='/') {
+                          strncpy(thedir, optarg, dirlen-1);
+                        }
+                        else {
+                          strncpy(thedir, optarg, dirlen);
+                        }
+                        break;
 		case 'f':	/* Force factor */
 			x=atoi(optarg);
 			if(x < 0)
@@ -471,6 +489,7 @@ dir_create(int x)
 	char buf[100];
 	stats[_STAT_DIR_CREATE].best=(double)99999.9;
 	stats[_STAT_DIR_CREATE].worst=(double)0.00000000;
+	chdir(thedir); /* change starting point */
 	for(i=0;i<x;i++)
 	{
 	  sprintf(buf,"iozone_L1_%d",i);
@@ -526,6 +545,7 @@ file_create(int x)
 	int fd;
 	int ret;
 	char buf[100];
+	char value;
 	stats[_STAT_CREATE].best=(double)999999.9;
 	stats[_STAT_CREATE].worst=(double)0.0;
 	stats[_STAT_WRITE].best=(double)999999.9;
@@ -555,6 +575,8 @@ file_create(int x)
 	    for(k=0;k<x;k++)
 	    {
 	      sprintf(buf,"iozone_file_%d_%d_%d",i,j,k);
+	      value=(char) ((i^j^k) & 0xff);
+	      memset(mbuffer,value,sz);
 	      stats[_STAT_CREATE].starttime=time_so_far();
 	      fd=creat(buf,O_RDWR|0600);
 	      if(fd < 0)
@@ -967,6 +989,7 @@ file_read(int x)
 {
 	int i,j,k,y,fd;
 	char buf[100];
+	char value;
 	stats[_STAT_READ].best=(double)99999.9;
 	stats[_STAT_READ].worst=(double)0.00000000;
 	for(i=0;i<x;i++)
@@ -980,6 +1003,7 @@ file_read(int x)
 	    for(k=0;k<x;k++)
 	    {
 	      sprintf(buf,"iozone_file_%d_%d_%d",i,j,k);
+	      value=(char)((i^j^k) &0xff);
 	      fd=open(buf,O_RDONLY);
 	      if(fd < 0)
 	      {
@@ -993,6 +1017,8 @@ file_read(int x)
 	        printf("Read failed\n");
 	        exit(1);
 	      }
+	      if(validate(mbuffer,sz, value) !=0)
+		printf("Error: Data Mis-compare\n");;
 	      stats[_STAT_READ].endtime=time_so_far();
 	      close(fd);
 	      stats[_STAT_READ].speed=stats[_STAT_READ].endtime-stats[_STAT_READ].starttime;
@@ -1109,3 +1135,21 @@ clear_stats()
 	for(i=0;i<_NUM_STATS;i++)
 		bzero((char *)&stats[i],sizeof(struct stat_struct));
 }
+int
+validate(char *buffer, int size, char value)
+{
+	register int i;
+	register char *cp;
+	register int size1;
+	register char v1;
+	v1=value;
+	cp = buffer;
+	size1=size;
+	for(i=0;i<size;i++)
+	{
+		if(*cp++ != v1)
+			return(1);
+	}
+	return(0);
+}
+
